Healthcare worker in Scotland diagnosed with Ebola | Reuters
Description: LONDON (Reuters) - A healthcare worker has been diagnosed with Ebola a day after flying home to Glasgow from Sierra Leone, the Scottish government said on Monday.The patient is being treated in isolation
Keywords: Guinea, Liberia, Morocco, Scotland, Sierra Leone, United Kingdom, Cameron, William Pooley

- Edition:
  UK
  - Africa
  - Arabic
  - Argentina
  - Brazil
  - Canada
  - China
  - France
  - Germany
  - India
  - Italy
  - Japan
  - Latin America
  - Mexico
  - Russia
  - Spain
  - United States

- Article
- Comments (0)
- Slideshow

# Healthcare worker in Scotland diagnosed with Ebola

LONDON Mon Dec 29, 2014 8:57pm GMT

- Tweet
- Link this
- Share this
- LONDON (Reuters) - A healthcare worker has been diagnosed with Ebola a day after flying home to Glasgow from Sierra Leone, the Scottish government said on Monday. The patient is being treated in isolation at Glasgow's Gartnavel Hospital, having flown...
- Email
- Print

1 of 2. A general view of Gartnavel General Hospital is seen in Glasgow, Scotland December 29, 2014.

Credit: Reuters/Stringer

### Related Topics

- UK »
- Africa »

LONDON (Reuters) - A healthcare worker has been diagnosed with Ebola a day after flying home to Glasgow from Sierra Leone, the Scottish government said on Monday.

The patient is being treated in isolation at Glasgow's Gartnavel Hospital, having flown back to Scotland's largest city late on Sunday on a British Airways flight via Casablanca in Morocco and London's Heathrow.

"All possible contacts with the patient are now being investigated and anyone deemed to be at risk will be contacted and closely monitored," the Scottish government said in a statement.

"However, having been diagnosed in the very early stages of the illness, the risk to others is considered extremely low."

The patient, whom BBC sources described as a female aid worker, will be transferred to a high-level isolation unit in the Royal Free hospital in London.

British Prime Minister Cameron has been informed, the Scottish government added.

In August, another British aid worker, William Pooley, contracted the disease after working Sierra Leone. He was discharged in September after treatment at the Royal Free hospital.

With more than 9,000 cases, Sierra Leone now accounts for nearly half of the known cases of Ebola in this year's West African outbreak, the worst ever. Neighbouring Liberia and Guinea have also been badly hit.

The World Health Organization on Monday said the number of people infected by Ebola in Liberia, Sierra Leone and Guinea -- the worst affected by the outbreak -- has passed 20,000, with more than 7,842 deaths in the epidemic so far.

(Reporting by Andy Bruce in London and Ankur Banerjee in Bengaluru; Editing by Joyjeet Das)

FILED UNDER:
UK
Africa

- Tweet this
- Link this
- Share this
- Digg this
- Email
- Print
- Reprints

### Trending On Reuters

### Follow Reuters

- Facebook
- Twitter
- RSS
- YouTube

- Edition:
  UK
  - Arabic
  - Argentina
  - Brazil
  - Canada
  - China
  - France
  - Germany
  - India
  - Italy
  - Japan
  - Latin America
  - Mexico
  - Russia
  - Spain
  - United States

Back to top

Reuters.com

- Business
- Markets
- World
- Politics
- Technology
- Opinion
- Money
- Pictures
- Videos
- Site Index
- Mobile
- Reuters Toolbar

More from Reuters

- Reuters News Agency
- Brand Attribution Guidelines
- Delivery Options

Support & Contact

- Support
- Corrections

Connect with Reuters

- Twitter
- Facebook
- LinkedIn
- RSS
- Newsletters

About

- Privacy Policy
- Terms of Use
- Copyright

Our Flagship financial information platform incorporating Reuters Insider
An ultra-low latency infrastructure for electronic trading and data distribution
A connected approach to governance, risk and compliance
Our next generation legal research platform
Our global tax workstation

- Thomsonreuters.com
- About Thomson Reuters
- Investor Relations
- Careers
- Contact Us

Thomson Reuters is the world's largest international multimedia news agency, providing investing news, world news, business news, technology news, headline news, small business news, news alerts, personal finance, stock market, and mutual funds information available on Reuters.com, video, mobile, and interactive television platforms. Thomson Reuters journalists are subject to an Editorial Handbook which requires fair presentation and disclosure of relevant interests.

NYSE and AMEX quotes delayed by at least 20 minutes. Nasdaq delayed by at least 15 minutes. For a complete list of exchanges and delays, please click here.